@@ -1,43 +1,35 @@
 /*
-    Copyright 2007-2009 Fela Winkelmolen <fela.kde@gmail.com>
-    Copyright 2010 Brian Croom <brian.s.croom@gmail.com>
+    SPDX-FileCopyrightText: 2007-2009 Fela Winkelmolen <fela.kde@gmail.com>
+    SPDX-FileCopyrightText: 2010 Brian Croom <brian.s.croom@gmail.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "mainwindow.h"
+
+// own
 #include "gameengine.h"
 #include "canvaswidget.h"
 #include "ui_generalsettings.h"
 #include "settings.h"
 #include "globals.h"
-
-#include <QPointer>
-
-#include <QMenuBar>
-#include <QIcon>
-#include <QAction>
-#include <KStandardAction>
-#include <KToggleFullScreenAction>
-#include <KActionCollection>
-#include <QKeySequence>
-#include <KMessageBox>
-#include <KConfigDialog>
+// KDEGames
 #include <KScoreDialog>
 #include <KgThemeSelector>
 #include <KStandardGameAction>
+// KF
+#include <KStandardAction>
+#include <KToggleFullScreenAction>
+#include <KActionCollection>
+#include <KMessageBox>
+#include <KConfigDialog>
 #include <KConfig>
+// Qt
+#include <QPointer>
+#include <QMenuBar>
+#include <QIcon>
+#include <QAction>
+#include <QKeySequence>
 
 class GeneralSettings : public QWidget
 {
@@ -100,19 +92,16 @@ MainWindow::~MainWindow()
 
 void MainWindow::setupActions()
 {
-    KStandardGameAction::gameNew(this, SLOT(startNewGame()),
-                                 actionCollection());
+    KStandardGameAction::gameNew(this, &MainWindow::startNewGame, actionCollection());
 
-    KStandardGameAction::quit(this, SLOT(close()), actionCollection());
+    KStandardGameAction::quit(this, &MainWindow::close, actionCollection());
 
-    KStandardGameAction::highscores(this, SLOT(showHighscores()),
-                                    actionCollection());
+    KStandardGameAction::highscores(this, &MainWindow::showHighscores, actionCollection());
 
-    KStandardAction::preferences(this, SLOT(configureSettings()),
-                                 actionCollection());
+    KStandardAction::preferences(this, &MainWindow::configureSettings, actionCollection());
 
     QAction *fullScreenAction = KStandardAction::fullScreen(this,
-                                SLOT(viewFullScreen(bool)), this, actionCollection());
+                                &MainWindow::viewFullScreen, this, actionCollection());
     // set the default primary shortcut as alternate shortcut
     // and make F the default
     QKeySequence fullScreenShortcut(i18nc("Key (shortcut) to toggle full screen", "F"));
@@ -141,8 +130,7 @@ void MainWindow::setupActions()
         actionCollection()->addAction(QStringLiteral("cheatAddLife"), cheatAddLifeAction);
     }
 
-    pauseAction = KStandardGameAction::pause(this,
-                  SLOT(setGamePaused(bool)), actionCollection());
+    pauseAction = KStandardGameAction::pause(this, &MainWindow::setGamePaused, actionCollection());
     // set custom keys
     QList<QKeySequence> keys;
     keys.append(i18nc("Key (shortcut) to pause the game", "P"));
